@@ -1,10 +1,11 @@
 package MooseX::ClassAttribute::Trait::Mixin::HasClassAttributes;
+BEGIN {
+  $MooseX::ClassAttribute::Trait::Mixin::HasClassAttributes::VERSION = '0.14';
+}
 
 use strict;
 use warnings;
 
-our $VERSION   = '0.13';
-
 use namespace::autoclean;
 use Moose::Role;
 
@@ -76,7 +77,9 @@ sub remove_class_attribute {
 
 1;
 
-__END__
+# ABSTRACT: A mixin trait for things which have class attributes
+
+
 
 =pod
 
@@ -84,6 +87,10 @@ __END__
 
 MooseX::ClassAttribute::Trait::Mixin::HasClassAttributes - A mixin trait for things which have class attributes
 
+=head1 VERSION
+
+version 0.14
+
 =head1 DESCRIPTION
 
 This trait is like L<Class::MOP::Mixin::HasAttributes>, except that it works
@@ -92,19 +99,24 @@ with class attributes instead of object attributes.
 See L<MooseX::ClassAttribute::Trait::Class> and
 L<MooseX::ClassAttribute::Trait::Role> for API details.
 
-=head1 AUTHOR
-
-Dave Rolsky, C<< <autarch@urth.org> >>
-
 =head1 BUGS
 
 See L<MooseX::ClassAttribute> for details.
 
-=head1 COPYRIGHT & LICENSE
+=head1 AUTHOR
 
-Copyright 2007-2010 Dave Rolsky, All Rights Reserved.
+  Dave Rolsky <autarch@urth.org>
 
-This program is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
+
+This software is Copyright (c) 2010 by Dave Rolsky.
+
+This is free software, licensed under:
+
+  The Artistic License 2.0
 
 =cut
+
+
+__END__
+
